Module anstyle_utils

Module anstyle_utils 

Utilities for working with anstyle types and bridging to ratatui.

Deprecated: Use vtcode_design::color and vtcode_design::style instead. This module is retained for backward compatibility but will be removed in a future version.

Functions

ansi_color_to_ratatui_colorDeprecated
Convert anstyle Color to ratatui Color directly.
ansi_effects_to_ratatui_modifiersDeprecated
Convert anstyle Effects to ratatui Modifiers.
ansi_style_to_ratatui_styleDeprecated
Convert an style directly to a ratatui Style using manual mapping.
anstyle_to_ratatuiDeprecated
Convert an anstyle Style to a ratatui Style using anstyle-crossterm as a bridge.
bg_colorDeprecated
Create a ratatui Style with a background color from anstyle.
bg_colored_with_effectsDeprecated
Create a ratatui Style with background color and effects.
build_ratatui_styleDeprecated
A convenience function that combines color, background, and effects into a single ratatui Style.
colored_with_effectsDeprecated
Create a ratatui Style with foreground color and effects.
fg_bg_colorsDeprecated
Create a ratatui Style with foreground and background colors.
fg_colorDeprecated
Create a ratatui Style with a foreground color from anstyle.
full_styleDeprecated
Create a complete ratatui Style from anstyle colors and effects.
with_effectsDeprecated
Create a ratatui Style with effects/modifiers.