pub fn compute_diff<F>(
old: &str,
new: &str,
options: DiffOptions<'_>,
formatter: F,
) -> DiffBundleExpand description
Compute a diff through the extracted implementation while preserving the legacy options type.
pub fn compute_diff<F>(
old: &str,
new: &str,
options: DiffOptions<'_>,
formatter: F,
) -> DiffBundleCompute a diff through the extracted implementation while preserving the legacy options type.