pub fn display_lines_from_hunks(hunks: &[DiffHunk]) -> Vec<DiffDisplayLine>Expand description
Converts hunks to semantic display lines and bounded intraline ranges.
pub fn display_lines_from_hunks(hunks: &[DiffHunk]) -> Vec<DiffDisplayLine>Converts hunks to semantic display lines and bounded intraline ranges.