pub fn diff_add_bg(theme: DiffTheme, level: DiffColorLevel) -> ColorExpand description
Get background color for addition lines based on theme and color level.
pub fn diff_add_bg(theme: DiffTheme, level: DiffColorLevel) -> ColorGet background color for addition lines based on theme and color level.