set_var

Function set_var 

pub fn set_var(key: impl AsRef<OsStr>, value: impl AsRef<OsStr>)
One-shot safe wrapper around std::env::set_var.

Acquires the process-wide environment lock for the duration of the call. Use lock when you need to perform multiple env operations atomically.