pub fn is_sensitive_file(name: &str) -> boolExpand description
Returns true if name matches any entry in SENSITIVE_FILES or
starts with .env. (catches all dotenv variants).
pub fn is_sensitive_file(name: &str) -> boolReturns true if name matches any entry in SENSITIVE_FILES or
starts with .env. (catches all dotenv variants).