open_directory_handle

Function open_directory_handle 

pub fn open_directory_handle(path: &Path) -> Result<File>
Open an absolute directory as a live handle for operations that must keep using the same directory even if an attacker renames a path component.