write_file_beneath

Function write_file_beneath 

pub fn write_file_beneath(
    root: &Path,
    relative: &Path,
    contents: &[u8],
) -> Result<()>
Write a new file beneath a trusted root while directory and file handles remain bound to that root. Existing files (including symlinks) are never replaced.