write_private_file_atomic_if_absent

Function write_private_file_atomic_if_absent 

pub async fn write_private_file_atomic_if_absent(
    path: &Path,
    contents: impl AsRef<[u8]>,
) -> Result<bool>
Atomically create a category-owned private file when the destination is absent.

Returns true when this call published the file and false when another writer had already created it.