resident_set_size_mb

Function resident_set_size_mb 

pub fn resident_set_size_mb() -> Option<f64>
Returns the current process Resident Set Size in megabytes, or None if it cannot be determined on the current platform.