pub struct MessageMetadata { /* private fields */ }Expand description
Metadata attached to every message in the conversation history.
Skipped during serialization when None to preserve backward compatibility
with all existing persistence formats (session archives, snapshots, etc.).
Implementations
Sourceimpl MessageMetadata
impl MessageMetadata
Sourcepub fn user_input(timestamp: u64, estimated_tokens: usize) -> Self
pub fn user_input(timestamp: u64, estimated_tokens: usize) -> Self
Create metadata for a message originating from a user.
Sourcepub fn llm_response(timestamp: u64, estimated_tokens: usize) -> Self
pub fn llm_response(timestamp: u64, estimated_tokens: usize) -> Self
Create metadata for a message originating from an LLM response.
Sourcepub fn tool_result(timestamp: u64, estimated_tokens: usize) -> Self
pub fn tool_result(timestamp: u64, estimated_tokens: usize) -> Self
Create metadata for a tool result message.