designate_main_thread

Function designate_main_thread 

pub fn designate_main_thread()
Designate the calling thread as the application’s main thread.

Should be invoked once, early in main, before spawning any worker threads that may try to obtain a MainThreadToken. Subsequent calls have no effect.