pub struct SendWrapper<T> { /* private fields */ }Expand description
A wrapper that allows sending non-Send types across thread boundaries.
Re-exported from the send_wrapper crate. It implements Send and Sync
regardless of whether the wrapped type is thread-safe. However, it will
panic at runtime if the wrapped value is accessed from any thread other
than the one that created it.
A wrapper which allows you to move around non-Send-types between threads, as long as you access the contained
value only from within the original thread and make sure that it is dropped from within the original thread.
Implementations
Sourceimpl<T> SendWrapper<T>
impl<T> SendWrapper<T>