pub fn looks_like_diff_content(content: &str) -> boolExpand description
Heuristic classifier for unified/git diff content.
This intentionally avoids classifying plain source code containing +/-
lines as a diff unless there are structural diff markers.