Module diff_theme

Module diff_theme 

Diff theme configuration and color palettes

Uses standard ANSI red/green for diff line backgrounds.

Enums

DiffColorLevel
Terminal color capability level for palette selection.
DiffTheme
Terminal background theme for diff rendering.

Functions

diff_add_bg
Get background color for addition lines based on theme and color level.
diff_del_bg
Get background color for deletion lines based on theme and color level.
diff_gutter_bg_add_light
Get gutter background color for addition lines in light theme.
diff_gutter_bg_del_light
Get gutter background color for deletion lines in light theme.
diff_gutter_fg_light
Get gutter foreground color for light theme (dark theme uses dimmed default).