Diff theme configuration and color palettes
Uses standard ANSI red/green for diff line backgrounds.
Enums
- Diff
Color Level - Terminal color capability level for palette selection.
- Diff
Theme - Terminal background theme for diff rendering.
Functions
- diff_
add_ bg - Get background color for addition lines based on theme and color level.
- diff_
del_ bg - Get background color for deletion lines based on theme and color level.
- diff_
gutter_ bg_ add_ light - Get gutter background color for addition lines in light theme.
- diff_
gutter_ bg_ del_ light - Get gutter background color for deletion lines in light theme.
- diff_
gutter_ fg_ light - Get gutter foreground color for light theme (dark theme uses dimmed default).