pub fn remove_var(key: impl AsRef<OsStr>)Expand description
One-shot safe wrapper around std::env::remove_var.
Acquires the process-wide environment lock for the duration of the call.
Use lock when you need to perform multiple env operations atomically.