copy_file_beneath

Function copy_file_beneath 

pub fn copy_file_beneath(
    source_root: &Path,
    source_relative: &Path,
    destination_root: &Path,
    destination_relative: &Path,
) -> Result<()>
Copy a regular file between two trusted roots without resolving a path after its parent has been validated. The destination must not already exist.