Serde helper utilities
Functions
- deserialize_
maybe_ quoted - Deserializes a value that can be represented as either its native type or a quoted string. This is particularly useful for LLM tool calls which sometimes quote numeric arguments.
- deserialize_
opt_ maybe_ quoted - Deserializes an optional value that can be represented as either its native type or a quoted string.
- json_
to_ string_ pretty - Render a
serde_json::Valueas pretty-printed JSON, falling back to itsDisplayimpl when the value cannot be serialized.