Thread Safety Primitives
Based on “Formal methods for the unsafe side of the Force” (Antithesis, 2026). Provides rigorously defined primitives for bridging FFI and multi-threaded boundaries.
Structs
- Main
Thread Token - A witness of execution that exists solely on a designated “Main Thread”.
- Send
Wrapper - A wrapper that allows sending non-
Sendtypes across thread boundaries.