SendWrapper

Struct SendWrapper 

pub struct SendWrapper<T> { /* private fields */ }
A wrapper that allows sending non-Send types across thread boundaries.

Re-exported from the send_wrapper crate. It implements Send and Sync regardless of whether the wrapped type is thread-safe. However, it will panic at runtime if the wrapped value is accessed from any thread other than the one that created it. A wrapper which allows you to move around non-Send-types between threads, as long as you access the contained value only from within the original thread and make sure that it is dropped from within the original thread.

Implementations

Source

impl<T> SendWrapper<T>

pub fn new(data: T) -> SendWrapper<T>

Create a SendWrapper<T> wrapper around a value of type T. The wrapper takes ownership of the value.

pub fn valid(&self) -> bool

Returns true if the value can be safely accessed from within the current thread.

pub fn take(self) -> T

Takes the value out of the SendWrapper<T>.

Panics

Panics if it is called from a different thread than the one the SendWrapper<T> instance has been created with.